@@ -153,7 +153,7 @@ static gboolean gnc_sxed_check_consistent( GncSxEditorDialog *sxed );
 static gboolean gnc_sxed_check_changed( GncSxEditorDialog *sxed );
 static void gnc_sxed_save_sx( GncSxEditorDialog *sxed );
 static void gnc_sxed_freq_changed( GncFrequency *gf, gpointer ud );
-static void sxed_excal_update_adapt_cb( GtkObject *o, gpointer ud );
+static void sxed_excal_update_adapt_cb( GtkWidget *o, gpointer ud );
 static void gnc_sxed_update_cal(GncSxEditorDialog *sxed);
 void on_sx_check_toggled_cb (GtkWidget *togglebutton, gpointer user_data);
 static void gnc_sxed_reg_check_close(GncSxEditorDialog *sxed);
@@ -608,6 +608,7 @@ gnc_sxed_check_consistent( GncSxEditorDialog *sxed )
                 Account *acct;
                 gnc_commodity *split_cmdty;
                 txnCreditDebitSums *tcds;
+                gnc_numeric split_amount;
 
                 s = (Split*)splitList->data;
                 t = xaccSplitGetParent( s );
@@ -632,11 +633,14 @@ gnc_sxed_check_consistent( GncSxEditorDialog *sxed )
                 acct_guid = kvp_value_get_guid( v );
                 acct = xaccAccountLookup( acct_guid, gnc_get_current_book ());
                 split_cmdty = xaccAccountGetCommodity(acct);
-                if (base_cmdty == NULL)
+                split_amount = xaccSplitGetAmount(s);
+                if (!gnc_numeric_zero_p(split_amount) && base_cmdty == NULL)
                 {
                     base_cmdty = split_cmdty;
                 }
-                multi_commodity |= !gnc_commodity_equal(split_cmdty, base_cmdty);
+                multi_commodity |= (!gnc_numeric_zero_p(split_amount) &&
+                                    !gnc_commodity_equal(split_cmdty,
+                                                         base_cmdty));
 
                 v = kvp_frame_get_slot_path( f,
                                              GNC_SX_ID,
@@ -792,6 +796,7 @@ gnc_sxed_check_consistent( GncSxEditorDialog *sxed )
         {
             gnc_warning_dialog(sxed->dialog, "%s",
                                _("Scheduled Transactions with variables "
+                                 "or involving more than one commodity "
                                  "cannot be automatically created."));
             return FALSE;
         }
@@ -1011,21 +1016,21 @@ gnc_sxed_save_sx( GncSxEditorDialog *sxed )
 
 
 static void
-enabled_toggled_cb( GtkObject *o, GncSxEditorDialog *sxed )
+enabled_toggled_cb( GtkToggleButton *o, GncSxEditorDialog *sxed )
 {
     return;
 }
 
 
 static void
-autocreate_toggled_cb( GtkObject *o, GncSxEditorDialog *sxed )
+autocreate_toggled_cb( GtkToggleButton *o, GncSxEditorDialog *sxed )
 {
-    if ( !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(o)) )
+    if ( !gtk_toggle_button_get_active (o) )
     {
         gtk_toggle_button_set_active( sxed->notifyOpt, FALSE );
     }
     gtk_widget_set_sensitive( GTK_WIDGET(sxed->notifyOpt),
-                              gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(o) ) );
+                              gtk_toggle_button_get_active (o) );
 }
 
 
@@ -1051,7 +1056,7 @@ remind_toggled_cb( GtkButton *o, GncSxEditorDialog *sxed )
 
 /* Local destruction of dialog */
 static void
-scheduledxaction_editor_dialog_destroy(GtkObject *object, gpointer data)
+scheduledxaction_editor_dialog_destroy(GtkWidget *object, gpointer data)
 {
     GncSxEditorDialog *sxed = data;
 
@@ -1662,7 +1667,7 @@ gnc_sxed_freq_changed(GncFrequency *gf, gpointer ud)
 
 
 static void
-sxed_excal_update_adapt_cb(GtkObject *o, gpointer ud)
+sxed_excal_update_adapt_cb(GtkWidget *o, gpointer ud)
 {
     gnc_sxed_update_cal((GncSxEditorDialog*)ud);
 }
